/**
 * @file
 * Author: Synapse-studio.
 */

(function ($) {
  $(document).ready(function () {
    ymaps.ready(ymapsInit);

    function ymapsInit() {
      var pos = '<div class="ymap"><div id="synmap" style="min-height:500px"></div></div>';
      var mapData = drupalSettings.synmap;
      if (drupalSettings.synmapReplace) {
        // MapData REPLACE.
        mapData = drupalSettings.synmapReplace;
      }
      
      var mapCenterLat = mapData.map.offsetX ? parseFloat(mapData.map.latitude) + parseFloat(mapData.map.offsetX) : mapData.map.latitude;
      var mapCenterLng = mapData.map.offsetY ? parseFloat(mapData.map.longitude) + parseFloat(mapData.map.offsetY) : mapData.map.longitude;

      // Map.
      $(mapData.map.attach).before(pos);
      var map = new ymaps.Map('synmap', {
        center: [mapCenterLng, mapCenterLat],
        zoom: mapData.map.zoom,
        controls: ['zoomControl', 'fullscreenControl']
      });
      map.behaviors.disable('scrollZoom');

      // Point params.
      var faClass = 'fa-map-marker-alt',
          faShape = {
            type: 'Rectangle',
            coordinates: [[-10, -10], [65, 80]]
          },
          faOffset = [-22, -73],
          pointCounter = 0;

      var pointsCollection = new ymaps.GeoObjectCollection();

      $.each(mapData.data, function (index, POINT) {

        pointCounter++;

        var pointID = `point${pointCounter}`,

            pointLayout = {
              iconLayout: ymaps.templateLayoutFactory.createClass(
                `<i id="${pointID}" class="${pointID} fas ${faClass}">
                  <div><span>${POINT.name}</span></div>
                </i>`
              ),
              iconContent: 'Active',
              iconShape: faShape,
              iconOffset: faOffset,
            },

            Placemark = new ymaps.Placemark(
              [POINT.longitude, POINT.latitude], {}, pointLayout
            );

        Placemark.events
          .add('click', function () {
            $('#' + pointID).toggleClass('hover')
          })
          .add('mouseenter', function () {
            $('#' + pointID).addClass('hover')
          })
          .add('mouseleave', function () {
            $('#' + pointID).removeClass('hover')
          })

        pointsCollection.add(Placemark)

      });

      // pointsCollection.events.add('click', function (e) {
      //   var POINT = e.get('target');
      // })

      map.geoObjects.add(pointsCollection);

      // Center Position.
      if (mapData.map.centerAuto === true) {
        var bounds = map.geoObjects.getBounds();
        map.setBounds(bounds, {
          checkZoomRange: true
        }).then(function () {
          if (map.getZoom() > 16) {
            map.setZoom(16);
          }
        });
      } else {
        // Move center.
        var position = map.getGlobalPixelCenter();
        map.setGlobalPixelCenter([
          position[0] - mapData.map.centerAutoX,
          position[1] - mapData.map.centerAutoY
        ]);
      }
    }
  });
})(this.jQuery);
